summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorSree Harsha Totakura <sreeharsha@totakura.in>2015-05-27 14:20:07 +0200
committerSree Harsha Totakura <sreeharsha@totakura.in>2015-05-27 14:20:07 +0200
commit1d551bf36b5e7d47dead516d42ece48420809fb4 (patch)
tree63a43b49429e609a62b769693c33d87f6b5fd316 /src/include
parent02c237d2699b354b05763831afb40cac18e17468 (diff)
downloadexchange-1d551bf36b5e7d47dead516d42ece48420809fb4.tar.gz
exchange-1d551bf36b5e7d47dead516d42ece48420809fb4.tar.bz2
exchange-1d551bf36b5e7d47dead516d42ece48420809fb4.zip
mintdb get_known_coin(): Do not allocate memory for return paramter.
Instead populate the fields of the placeholder return variable.
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_mintdb_plugin.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/taler_mintdb_plugin.h b/src/include/taler_mintdb_plugin.h
index 0cbcb3c4e..63dacf73b 100644
--- a/src/include/taler_mintdb_plugin.h
+++ b/src/include/taler_mintdb_plugin.h
@@ -332,7 +332,7 @@ struct TALER_MINTDB_RefreshMelt
*/
struct TALER_Amount amount_with_fee;
- /**
+ /** FIXME: This can be retrieved from the Denomination? Do we need this?
* Melting fee charged by the mint. This must match the Mint's
* denomination key's melting fee. If the client puts in an invalid
* melting fee (too high or too low) that does not match the Mint's
@@ -848,7 +848,7 @@ struct TALER_MINTDB_Plugin
* @param cls the plugin closure
* @param session the database session handle
* @param coin_pub the public key of the coin to search for
* @param ret_coin_info place holder for the returned coin information object
* @return #GNUNET_SYSERR upon error; #GNUNET_NO if no coin is found; #GNUNET_OK
* if upon succesfullying retrieving the record data info @a
* ret_coin_info
@@ -857,7 +857,7 @@ struct TALER_MINTDB_Plugin
(*get_known_coin) (void *cls,
struct TALER_MINTDB_Session *session,
const struct TALER_CoinSpendPublicKeyP *coin_pub,
- struct TALER_CoinPublicInfo **ret_coin_info);
+ struct TALER_CoinPublicInfo *coin_info);
/**
@@ -848,7 +848,7 @@ struct TALER_MINTDB_Plugin
* @param session the database session handle
* @param coin_pub the public key of the coin to search for
- * @param ret_coin_info place holder for the returned coin information object
+ * @param coin_info place holder for the returned coin information object
* @return #GNUNET_SYSERR upon error; #GNUNET_NO if no coin is found; #GNUNET_OK
* if upon succesfullying retrieving the record data info @a